@@ -18,7 +18,9 @@ def entityTypeList(args, configuration):
             }
         }
     }
-    variablesObj = { "accountID": (params.get("accountID") if params.get("accountID") else params.get("accountId"))}
+    # Use accountID from configuration (profile) or fall back to command line parameter
+    account_id = configuration.accountID if configuration and hasattr(configuration, 'accountID') else (params.get("accountID") or params.get("accountId"))
+    variablesObj = { "accountID": account_id }
 
     # Create the API client instance
     api_client = ApiClient(configuration)
@@ -251,7 +253,7 @@ def writeDataToFile(data, args, account_id=None, default_filename_template="data
     
     Args:
         data: The data to write to file (will be JSON serialized)
-        args: Command line arguments containing output_file_path and verbose options
+        args: Command line arguments containing output_file_path, output_directory and verbose options
         account_id: Optional account ID for default filename generation
         default_filename_template: Template for default filename (use {account_id} placeholder)
         default_directory: Default directory for output files
@@ -269,7 +271,14 @@ def writeDataToFile(data, args, account_id=None, default_filename_template="data
         if hasattr(args, 'verbose') and args.verbose:
             print(f"Using output file path: {output_file}")
     else:
-        destination_dir = default_directory
+        # Use output_directory from args if provided, otherwise use default_directory
+        if hasattr(args, 'output_directory') and args.output_directory:
+            destination_dir = args.output_directory
+            if hasattr(args, 'verbose') and args.verbose:
+                print(f"Using custom output directory: {destination_dir}")
+        else:
+            destination_dir = default_directory
+        
         if account_id:
             filename = default_filename_template.format(account_id=account_id)
         else:
